Merge pull request #226 from scchan/add_printf3

add printf to HIP device functions

[ROCm/hip commit: f8843ae415]
このコミットが含まれているのは:
Ben Sander
2017-10-30 17:08:18 +01:00
committed by GitHub
コミット 8242c45eda
3個のファイルの変更59行の追加1行の削除
+20
ファイルの表示
@@ -50,10 +50,16 @@ THE SOFTWARE.
#include <hip/hip_runtime_api.h>
// define HIP_ENABLE_PRINTF to enable printf
#ifdef HIP_ENABLE_PRINTF
#define HCC_ENABLE_ACCELERATOR_PRINTF 1
#endif
//---
// Remainder of this file only compiles with HCC
#if defined __HCC__
#include <grid_launch.h>
#include "hc_printf.hpp"
//TODO-HCC-GL - change this to typedef.
//typedef grid_launch_parm hipLaunchParm ;
@@ -420,6 +426,20 @@ static inline __device__ void* memset(void* ptr, int val, size_t size)
}
#ifdef __HCC_ACCELERATOR__
#ifdef HC_FEATURE_PRINTF
template <typename... All>
static inline __device__ void printf(const char* format, All... all) {
hc::printf(format, all...);
}
#else
template <typename... All>
static inline __device__ void printf(const char* format, All... all) { }
#endif
#endif
#define __syncthreads() hc_barrier(CLK_LOCAL_MEM_FENCE)
+1 -1
ファイルの表示
@@ -616,7 +616,7 @@ void ihipDevice_t::locked_reset()
//FIXME - Calling am_memtracker_reset is really bad since it destroyed all buffers allocated by the HCC runtime as well
//such as the printf buffer. Re-initialze the printf buffer as a workaround for now.
#if (__hcc_workweek__ >= 17423)
#ifdef HC_FEATURE_PRINTF
Kalmar::getContext()->initPrintfBuffer();
#endif
};
+38
ファイルの表示
@@ -0,0 +1,38 @@
/*
Copyright (c) 2015-2017 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
/* HIT_START
* BUILD: %t %s ../test_common.cpp
* RUN: %t
* HIT_END
*/
#define HIP_ENABLE_PRINTF
#include"test_common.h"
__global__ void run_printf(hipLaunchParm lp){
printf("Hello World\n");
}
int main(){
hipLaunchKernel(HIP_KERNEL_NAME(run_printf), dim3(1), dim3(1), 0, 0);
hipDeviceSynchronize();
passed();
}